@@ -43,7 +43,6 @@
 #include <gdk/gdktypes.h>
 #include <gtk/gtkwidget.h>
 
-#include <libgnomecanvas/gnome-canvas.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
 typedef struct EelBackground EelBackground;
@@ -72,6 +71,8 @@ EelBackground *             eel_background_new                              (voi
 
 
 /* Calls to change a background. */
+void                        eel_background_set_use_base                     (EelBackground               *background,
+									     gboolean                     use_base);
 void                        eel_background_set_color                        (EelBackground               *background,
 									     const char                  *color_or_gradient);
 void                        eel_background_set_image_uri                    (EelBackground               *background,
@@ -132,12 +133,7 @@ void                        eel_background_draw                             (Eel
 									     int                          dest_y,
 									     int                          dest_width,
 									     int                          dest_height);
-/* For updating the canvas, aa case. Note: eel_background_pre_draw
- * must have been previously called. Only intended to be called by
- * eel_background_canvas_group_render.
- */
-void                        eel_background_draw_aa                          (EelBackground               *background,
-									     GnomeCanvasBuf              *buffer);
+
 /* Used to fill a drawable with a background.
  *  - entire_width/height describe the total area the background covers
  *  - drawable_x/y/width/height describe the portion of that area the drawable covers
@@ -152,14 +148,6 @@ void                        eel_background_draw_to_drawable                 (Eel
 									     int                          entire_width,
 									     int                          entire_height);
 
-/* Used to fill a drawable with a background.
- *  - entire_width/height describe the total area the background covers
- *  - buffer is a portion of that area
- */
-void                        eel_background_draw_to_canvas                   (EelBackground               *background,
-									     GnomeCanvasBuf              *buffer,
-									     int                          entire_width,
-									     int                          entire_height);
 /* Used to fill a pixbuf with a background.
  *  - entire_width/height describe the total area the background covers
  *  - drawable_x/y/width/height describe the portion of that area the pixbuf covers
@@ -176,12 +164,14 @@ void                        eel_background_draw_to_pixbuf                   (Eel
 /* Handles a dragged color being dropped on a widget to change the background color. */
 void                        eel_background_receive_dropped_color            (EelBackground               *background,
 									     GtkWidget                   *widget,
+									     GdkDragAction                action,
 									     int                          drop_location_x,
 									     int                          drop_location_y,
 									     const GtkSelectionData      *dropped_color);
 
 /* Handles a special-case image name that means "reset to default background" too. */
 void                        eel_background_receive_dropped_background_image (EelBackground               *background,
+									     GdkDragAction                action,
 									     const char                  *image_uri);
 
 /* Gets or creates a background so that it's attached to a widget. */
@@ -216,6 +206,13 @@ struct EelBackgroundClass
 	 */
 	void (* appearance_changed) (EelBackground *);
 
+	/* This signal is emitted when image loading is over to
+	 * allow the placement of the background to be determined
+	 * from the geometry, ie. whether to tile or scale the image.
+	 */
+	EelBackgroundImagePlacement
+             (* determine_image_placement) (EelBackground *, int image_width, int image_height);
+ 
 	/* This signal is emitted when image loading is over - whether it
 	 * was successfully loaded or not.
 	 */
