@@ -112,6 +112,11 @@ void       eel_preferences_item_enumeration_list_set_unique_exceptions (EelPrefe
 									const char                      *exceptions_delimiter);
 void       eel_preferences_item_set_description                        (EelPreferencesItem              *preferences_item,
 									const char                      *description);
+void       eel_preferences_item_set_accessible_description             (EelPreferencesItem              *preferences_item,
+									const char                      *description);
+void       eel_preferences_item_set_accessible_description_array       (EelPreferencesItem              *preferences_item,
+									int                              n_descriptions,
+									const char                     **descriptions);
 
 G_END_DECLS
 
